@@ -1,20 +1,22 @@
 #' @title Number line objects
 #'
-#' @description \code{number_line} - A range of \code{numeric} based values on a number line.
+#' @description \code{number_line} - A range of \code{numeric} values on a number line.
 #'
 #' @details
 #' A \code{number_line} object represents a range of real numbers on a number line.
 #'
-#' Visually, it's presented as the left (\code{l}) and right (\code{r}) points of the range This may differ from \code{start} and \code{end} points.
-#' The \code{start} point is the lowest number in the range, regardless of whether it's at the \code{left} or \code{right} point.
+#' Visually, it's presented as the \code{left (l)} and \code{right (r) points} of the range. This may differ from \code{start} and \code{end points}.
+#' The \code{start point} is the lowest value in the range, regardless of whether it's at the \code{left} or \code{right point}.
 #'
 #' The location of the \code{start} point - \code{left} or \code{right}, indicates whether it's an \code{"increasing"} or \code{"decreasing"} range.
-#' This is the \code{direction} of the \code{number_line} object.
+#' This is the \code{direction} of the \code{number_line}.
+#' @seealso
+#'  \code{\link{overlaps}}, \code{\link{set_operations}}, \code{\link{episodes}} and \code{\link{links}}
 #'
-#' @param l Left point of the \code{number_line} object. Must be able to be coerced to a finite \code{numeric} value
-#' @param r Right point of the \code{number_line} object. Must be able to be coerced to a finite \code{numeric} value
-#' @param id Unique \code{numeric} element ID. Optional
-#' @param gid Unique \code{numeric} group ID. Optional
+#' @param l Left point of the \code{number_line} object. Must be able to be coerced to a \code{numeric} object
+#' @param r Right point of the \code{number_line} object. Must be able to be coerced to a \code{numeric} object
+#' @param id Unique \code{numeric} element identifier. Optional
+#' @param gid Unique \code{numeric} group identifier. Optional
 #'
 #' @return \code{number_line} object
 #'
@@ -34,43 +36,45 @@
 #'
 #' @export
 number_line <- function(l, r, id = NULL, gid = NULL){
-  er1 <- try(as.numeric(l), silent = TRUE)
-  er2 <- try(as.numeric(r), silent = TRUE)
-  er3 <- try(as.numeric(r) - as.numeric(l), silent = TRUE)
+  if(missing(l) & missing(r)) return(new("number_line"))
+  if(length(l) ==0 & length(r)==0) return(new("number_line"))
 
-  if(missing(l) & missing(r) & missing(id) & missing(gid)) return(new("number_line"))
-  if(length(l)!=length(r)) stop("'l' and 'r' have different lengths")
-  if(!is.numeric(er1) | !is.numeric(er2) | !is.numeric(er3)) stop(paste("'l' or 'r' aren't compatible for a number_line object",sep=""))
-  if(!(is.numeric(id) | is.null(id))) stop(paste("'id' must be numeric",sep=""))
-  if(!(is.numeric(gid) | is.null(gid))) stop(paste("'gid' must be numeric",sep=""))
-
-  if(all(class(l)!=class(r))) warning("'l' and 'r' have different classes. It may need to be reconciled")
+  er1 <- suppressWarnings(try(as.numeric(l), silent = TRUE))
+  er2 <- suppressWarnings(try(as.numeric(r), silent = TRUE))
+  er3 <- suppressWarnings(try(as.numeric(r) - as.numeric(l), silent = TRUE))
 
+  mxa <- max(c(length(l), length(r), length(id), length(gid)))
+  if(length(l)==1) l <- rep(l, mxa)
+  if(length(r)==1) r <- rep(r, mxa)
+  if(length(id)==1) id <- rep(id, mxa)
+  if(length(gid)==1) gid <- rep(gid, mxa)
   if(is.null(id) | any(!is.finite(id)) ) id <- 1:length(l)
   if(is.null(gid) | any(!is.finite(gid)) ) gid <- 1:length(l)
-  nl <- methods::new("number_line", .Data = as.numeric(r) - as.numeric(l), start=l, id = id, gid = gid)
+  if(length(l)!= mean(c(length(r),length(id),length(gid)))) stop("Argument lengths differ or are not equal to 1", call. = F)
+  if(!is.numeric(er1) | !is.numeric(er2) | !is.numeric(er3)) stop(paste("'l' or 'r' aren't compatible for a `number_line` object",sep=""), call. = F)
+  if(!(is.numeric(id) | is.null(id))) stop(paste("'id' must be `numeric`",sep=""), call. = F)
+  if(!(is.numeric(gid) | is.null(gid))) stop(paste("`gid` must be `numeric`",sep=""), call. = F)
+  if(all(class(l)!=class(r))) warning("`l` and `r` have different classes. They may need to be reconciled.", call. = F)
+
+  nl <- suppressWarnings(methods::new("number_line", .Data = ifelse(as.numeric(r) == as.numeric(l) & !is.na(r), 0, as.numeric(r) - as.numeric(l)), start=l, id = id, gid = gid))
   return(nl)
 }
 
 
 #' @rdname number_line
 #' @examples
-#' # Convert numeric based objects to number_line objects
+#' # Convert numeric based objects to `number_line` objects
 #' as.number_line(5.1); as.number_line(date("21/10/2019"))
 #'
 #' @export
 as.number_line <- function(x){
-
-  if(missing(x)) stop("argument 'x' is missing, with no default")
-
+  if(missing(x)) stop("argument `x` is missing, with no default", call. = F)
   er1 <- suppressWarnings(try(as.numeric(x), silent = TRUE))
   er2 <- suppressWarnings(try(as.numeric(x) + 0, silent = TRUE))
 
-  if(!is.numeric(er1) | !is.numeric(er2)) stop(paste("'x' can't be coerced to a `number_line` object",sep=""))
-
-  if(all(!diyar::is.number_line(x))){
-    x[!is.finite(as.numeric(x))] <- NA
-    x <- methods::new("number_line", .Data = as.numeric(x-x), start= x, id = 1:length(x), gid = 1:length(x))
+  if(!is.numeric(er1) | !is.numeric(er2)) stop("`x` can't be coerced to a `number_line` object.", call. = F)
+  if(all(!is.number_line(x))){
+    x <- methods::new("number_line", .Data = rep(0, length(x)), start= x, id = 1:length(x), gid = 1:length(x))
   }
 
   return(x)
@@ -84,7 +88,7 @@ as.number_line <- function(x){
 #' is.number_line(a); is.number_line(b)
 #'
 #' @export
-is.number_line <- function(x) class(x)=="number_line"
+is.number_line <- function(x) all(class(x) =="number_line")
 
 #' @rdname number_line
 #' @examples
@@ -93,8 +97,9 @@ is.number_line <- function(x) class(x)=="number_line"
 #'
 #' @export
 left_point <- function(x){
-  if(missing(x)) stop("argument 'x' is missing, with no default")
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
+  if(missing(x)) stop("argument `x` is missing, with no default", call. = F)
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
   x@start
 }
 
@@ -102,72 +107,82 @@ left_point <- function(x){
 #' @param value \code{numeric} based value
 #' @export
 "left_point<-" <- function(x, value) {
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
-  diyar::number_line(r =diyar::right_point(x),  l=value, id=x@id, gid=x@gid)
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
+  if(length(x)==0) return(number_line())
+  number_line(r =right_point(x),  l=value, id=x@id, gid=x@gid)
 }
 
 #' @rdname number_line
 #' @export
 right_point <- function(x){
-  if(missing(x)) stop("argument 'x' is missing, with no default")
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
+  if(missing(x)) stop("argument `x` is missing, with no default", call. = F)
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
   x@start + x@.Data
 }
 
 #' @rdname number_line
 #' @export
 "right_point<-" <- function(x, value) {
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
-  diyar::number_line(r=value,  l=x@start, id=x@id, gid=x@gid)
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
+  if(length(x)==0) return(number_line())
+  number_line(r=value,  l=x@start, id=x@id, gid=x@gid)
 }
 
 #' @rdname number_line
 #' @export
 start_point <- function(x){
-  if(missing(x)) stop("argument 'x' is missing, with no default")
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
-  x <- diyar::reverse_number_line(x,"decreasing")
+  if(missing(x)) stop("argument `x` is missing, with no default", call. = F)
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
+  x <- reverse_number_line(x,"decreasing")
   x@start
 }
 
 #' @rdname number_line
 #' @export
 "start_point<-" <- function(x, value) {
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
   l <- x@start; r <- value
   l[x@.Data >=0] <- value[x@.Data >=0]
   r[x@.Data >=0] <- (x@start + x@.Data)[x@.Data >=0]
 
-  diyar::number_line(l=l, r=r, id=x@id, gid=x@gid)
+  number_line(l=l, r=r, id=x@id, gid=x@gid)
 }
 
 #' @rdname number_line
 #' @export
 end_point <- function(x){
-  if(missing(x)) stop("argument 'x' is missing, with no default")
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
-  x <- diyar::reverse_number_line(x,"decreasing")
+  if(missing(x)) stop("argument `x` is missing, with no default", call. = F)
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
+  x <- reverse_number_line(x,"decreasing")
   x@start + x@.Data
 }
 
 #' @rdname number_line
 #' @export
 "end_point<-" <- function(x, value) {
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
 
   l <- value; r <- (x@start + x@.Data)
   l[x@.Data >=0] <- x@start[x@.Data >=0]
   r[x@.Data >=0] <- value[x@.Data >=0]
 
-  diyar::number_line(l=l, r=r, id=x@id, gid=x@gid)
+  number_line(l=l, r=r, id=x@id, gid=x@gid)
 }
 
 #' @rdname number_line
 #' @export
 number_line_width <- function(x){
-  if(missing(x)) stop("argument 'x' is missing, with no default")
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
-  diyar::right_point(x) - diyar::left_point(x)
+  if(missing(x)) stop("argument `x` is missing, with no default", call. = F)
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
+  right_point(x) - left_point(x)
 }
 
 #' @rdname number_line
@@ -177,8 +192,8 @@ number_line_width <- function(x){
 #' @details
 #' \bold{\code{reverse_number_line()}} - reverses the direction of a \code{number_line} object.
 #' A reversed \code{number_line} object has its \code{l} and \code{r} points swapped.
-#' The \code{direction} argument determines which type of \code{number_line} objects will be reversed.
-#' \code{number_line} objects with non-finite numeric starts or end points i.e. (\code{NA}, \code{NaN} and \code{Inf}) can't be reversed.
+#' The \code{direction} argument specifies which type of \code{number_line} objects will be reversed.
+#' \code{number_line} objects with non-finite \code{starts} or \code{end points} i.e. (\code{NA}, \code{NaN} and \code{Inf}) can't be reversed.
 #' @examples
 #' # Reverse number_line objects
 #' reverse_number_line(number_line(date("25/04/2019"), date("01/01/2019")))
@@ -187,26 +202,31 @@ number_line_width <- function(x){
 #'
 #' @export
 reverse_number_line <- function(x, direction = "both"){
-  if(missing(x)) stop("argument 'x' is missing, with no default")
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
+  if(missing(x)) stop("argument `x` is missing, with no default", call. = F)
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
   if(length(x)==0) return(x)
-  if(!(length(direction) %in% c(1, length(x)) & is.character(direction))) stop(paste("'direction' must be a character of length 1"))
-  direction <- tolower(direction)
-  if(any(!direction %in% c("increasing","decreasing","both")) ) stop(paste("`direction` must be either 'increasing', 'decreasing' or 'both'"))
+  err <- err_match_ref_len(direction, "x", c(1, length(x)), "direction")
+  if(err != F) stop(err, call. = F)
+  err <- err_object_types(direction, "direction", "character")
+  if(err != F) stop(err, call. = F)
+  err <- err_invalid_opts(direction, "direction", c("increasing","decreasing","both"))
+  if(err != F) stop(err, call. = F)
 
+  direction <- tolower(direction)
   fnt <- is.finite(as.numeric(x@start)) & is.finite(as.numeric(x@.Data))
 
-  x[direction=="increasing" & x@.Data>0 & fnt == T] <- diyar::number_line(l= x@start[direction=="increasing" & x@.Data>0 & fnt == T] + x@.Data[direction=="increasing" & x@.Data>0 & fnt == T],
+  x[direction=="increasing" & x@.Data>0 & fnt == T] <- number_line(l= x@start[direction=="increasing" & x@.Data>0 & fnt == T] + x@.Data[direction=="increasing" & x@.Data>0 & fnt == T],
                                                                r= x@start[direction=="increasing" & x@.Data>0 & fnt == T],
                                                                id=x@id[direction=="increasing" & x@.Data>0 & fnt == T],
                                                                gid=x@gid[direction=="increasing" & x@.Data>0 & fnt == T])
 
-  x[direction=="decreasing" & x@.Data<0 & fnt == T] <- diyar::number_line(l= x@start[direction=="decreasing" & x@.Data<0 & fnt == T] + x@.Data[direction=="decreasing" & x@.Data<0 & fnt == T],
+  x[direction=="decreasing" & x@.Data<0 & fnt == T] <- number_line(l= x@start[direction=="decreasing" & x@.Data<0 & fnt == T] + x@.Data[direction=="decreasing" & x@.Data<0 & fnt == T],
                                                                r= x@start[direction=="decreasing" & x@.Data<0 & fnt == T],
                                                                id= x@id[direction=="decreasing" & x@.Data<0 & fnt == T],
                                                                gid= x@gid[direction=="decreasing" & x@.Data<0 & fnt == T])
 
-  x[direction=="both" & x@.Data !=0 & fnt == T] <- diyar::number_line(l= x@start[direction=="both" & x@.Data !=0 & fnt == T] + x@.Data[direction=="both" & x@.Data !=0 & fnt == T],
+  x[direction=="both" & x@.Data !=0 & fnt == T] <- number_line(l= x@start[direction=="both" & x@.Data !=0 & fnt == T] + x@.Data[direction=="both" & x@.Data !=0 & fnt == T],
                                              r= x@start[direction=="both" & x@.Data !=0 & fnt == T],
                                              id= x@id[direction=="both" & x@.Data !=0 & fnt == T],
                                              gid= x@gid[direction=="both" & x@.Data !=0 & fnt == T])
@@ -221,16 +241,22 @@ reverse_number_line <- function(x, direction = "both"){
 #' # Shift number_line objects
 #' c <- number_line(5, 6)
 #' # Towards the positive end of the number line
-#' shift_number_line(x=c(c, c), by=c(2, 3))
+#' shift_number_line(x = c(c, c), by = c(2, 3))
 #' # Towards the negative end of the number line
-#' shift_number_line(x=c(c, c), by=c(-2, -3))
+#' shift_number_line(x = c(c, c), by = c(-2, -3))
 #'
 #' @export
-shift_number_line <- function(x, by=1){
-  if(missing(x)) stop("argument 'x' is missing, with no default")
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
+shift_number_line <- function(x, by = 1){
+  if(missing(x)) stop("argument `x` is missing, with no default", call. = F)
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
   if(length(x)==0) return(x)
-  if(!(length(by) %in% c(1, length(x)))) stop(paste("length of 'by' must be 1 or the same as 'x'",sep=""))
+  err <- err_match_ref_len(by, "x", c(1, length(x)), "by")
+  if(err != F) stop(err, call. = F)
+  err <- err_object_types(by, "by", c("numeric", "integer"))
+  if(err != F) stop(err, call. = F)
+  err <- err_missing_check(by, "by")
+  if(err != F) stop(err, call. = F)
 
   by[!is.finite(by)] <- NA_real_
   n <- ifelse(is.finite(x@start) & is.finite(x@.Data),1,0)
@@ -255,14 +281,23 @@ shift_number_line <- function(x, by=1){
 #' expand_number_line(d, 2, "end")
 #'
 #' @export
-expand_number_line <- function(x, by=1, point ="both"){
-  if(missing(x)) stop("argument 'x' is missing, with no default")
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
+expand_number_line <- function(x, by = 1, point ="both"){
+  if(missing(x)) stop("argument `x` is missing, with no default", call. = F)
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
   if(length(x)==0) return(x)
-  if(!all(is.character(point))) stop(paste("'point' must be a character object"))
-  if(all(!tolower(point) %in% c("both","start","end","left","right"))) stop(paste("`point` must be either 'left', 'right', 'start', 'end' or 'both'"))
-  if(!(length(by) %in% c(1, length(x)))) stop(paste("length of 'by' must be 1 or the same as 'x'",sep=""))
-  if(!(length(point) %in% c(1, length(x)))) stop(paste("length of 'point' must be 1 or the same as 'x'",sep=""))
+  err <- err_match_ref_len(by, "x", c(1, length(x)), "by")
+  if(err != F) stop(err, call. = F)
+  err <- err_match_ref_len(point, "x", c(1, length(x)), "point")
+  if(err != F) stop(err, call. = F)
+  err <- err_object_types(by, "by", c("numeric", "integer"))
+  if(err != F) stop(err, call. = F)
+  err <- err_missing_check(by, "by")
+  if(err != F) stop(err, call. = F)
+  err <- err_object_types(point, "point", "character")
+  if(err != F) stop(err, call. = F)
+  err <- err_invalid_opts(point, "point", c("both","start","end","left","right"))
+  if(err != F) stop(err, call. = F)
 
   point <- tolower(point)
   by[!is.finite(by)] <- NA_real_
@@ -286,9 +321,9 @@ expand_number_line <- function(x, by=1, point ="both"){
 
 #' @rdname number_line
 #' @details
-#' \bold{\code{invert_number_line()}} - Invert the \code{left} and/or \code{right} points to the opposite end of the number line.
+#' \bold{\code{invert_number_line()}} - Invert the \code{left} and/or \code{right} points from a negative to positive value or vice versa.
 #' @examples
-#' # Change the width or length of a number_line object
+#' # Invert `number_line` objects
 #' e <- c(number_line(3, 6), number_line(-3, -6), number_line(-3, 6))
 #'
 #' e
@@ -297,21 +332,25 @@ expand_number_line <- function(x, by=1, point ="both"){
 #' invert_number_line(e, "end")
 #'
 #' @export
-invert_number_line <- function(x, point ="both"){
-  if(missing(x)) stop("argument 'x' is missing, with no default")
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
+invert_number_line <- function(x, point = "both"){
+  if(missing(x)) stop("argument `x` is missing, with no default", call. = F)
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
   if(length(x)==0) return(x)
-  if(!all(is.character(point))) stop(paste("'point' must be a character object"))
-  if(all(!tolower(point) %in% c("both","start","end","left","right"))) stop(paste("`point` must be either 'left', 'right', 'start', 'end' or 'both'"))
-  if(!(length(point) %in% c(1, length(x)))) stop(paste("length of 'point' must be 1 or the same as 'x'",sep=""))
+  err <- err_match_ref_len(point, "x", c(1, length(x)), "point")
+  if(err != F) stop(err, call. = F)
+  err <- err_object_types(point, "point", "character")
+  if(err != F) stop(err, call. = F)
+  err <- err_invalid_opts(point, "point", c("both","start","end","left","right"))
+  if(err != F) stop(err, call. = F)
 
   point <- tolower(point)
 
   x <- number_line(l=as.numeric(x@start), r=as.numeric(x@start)+x@.Data, id=x@id, gid=x@gid)
   left_point(x[point=="left"]) <- -x@start[point=="left"]
   right_point(x[point=="right"]) <- -(x@start[point=="right"] + x@.Data[point=="right"])
-  start_point(x[point=="start"]) <- -diyar::start_point(x[point=="start"])
-  end_point(x[point=="end"]) <- -diyar::end_point(x[point=="end"])
+  start_point(x[point=="start"]) <- -start_point(x[point=="start"])
+  end_point(x[point=="end"]) <- -end_point(x[point=="end"])
   left_point(x[point=="both"]) <- -x@start[point=="both"]; right_point(x[point=="both"]) <- -(x@start[point=="both"] + x@.Data[point=="both"])
 
   return(x)
@@ -323,7 +362,7 @@ invert_number_line <- function(x, point ="both"){
 #' This results in duplicate \code{number_line} objects with the \code{start} and \code{end} points of the new expanded \code{number_line} object.
 #' See \code{\link{overlaps}} for further details on overlapping \code{number_line} objects.
 #' If a familiar (but unique) \code{id} is used when creating the \code{number_line} objects,
-#' \bold{\code{compress_number_line()}} can be an alternative for simple implementations of \code{\link{record_group}} or \code{\link{episode_group}}.
+#' \bold{\code{compress_number_line}} can be an alternative for simple implementations of \code{\link{links}} or \code{\link{episodes}}.
 #'
 #' @param method Method of overlap. Check every pair of \code{number_line} objects with the same \code{method}. Deprecated. Please use \code{methods} instead.
 #' @param methods Methods of overlap. Check different pairs of \code{number_line} objects with the different \code{methods}
@@ -340,20 +379,12 @@ invert_number_line <- function(x, point ="both"){
 #'
 #' @export
 
-compress_number_line <- function(x, method = c("exact", "across","chain","aligns_start","aligns_end","inbetween","overlap","none"), collapse =FALSE, deduplicate = TRUE, methods = "overlap"){
-  if(missing(x)) stop("argument 'x' is missing, with no default")
-  if(!diyar::is.number_line(x)) stop(paste("'x' is not a number_line object"))
+compress_number_line <- function(x, methods = "overlap", collapse = FALSE,
+                                 deduplicate = TRUE,  method = "overlap"){
+  if(missing(x)) stop("argument `x` is missing, with no default", call. = F)
+  err <- err_object_types(x, "x", c("number_line", "numeric", "integer"))
+  if(err != F) stop(err, call. = F)
   if(length(x)==0) return(x)
-  if(!is.character(method)) stop(paste("'method' must be a character object"))
-  if(!(is.logical(collapse) & is.logical(deduplicate) )) stop(paste("'collapse' and 'deduplicate' must be TRUE or FALSE"))
-  if(all(!tolower(method) %in% c("exact", "across","chain","aligns_start","aligns_end","inbetween", "overlap", "none"))) stop(paste("`method` must be either 'overlap', 'exact', 'across', 'chain', 'aligns_start', 'aligns_end', 'inbetween' or 'none'"))
-  if(!(length(collapse) %in% c(1, length(x)))) stop(paste("length of 'collapse' must be 1 or the same as 'x'",sep=""))
-  o <- unique(unlist(strsplit(methods, split="\\|")))
-  o <- o[!o %in% c("exact", "across","chain","aligns_start","aligns_end","inbetween", "overlap")]
-  if (length(o)>0) stop(paste("\n'", "Valid 'methods' are 'overlap', 'exact', 'across', 'chain', 'aligns_start', 'aligns_end' or 'inbetween' \n\n",
-                              "Syntax ~ \"method1|method2|method3...\" \n",
-                              "                 OR                   \n",
-                              "Use ~ include_overlap_method() or exclude_overlap_method()", sep=""))
   if(missing(methods) & !missing(method)) {
     m <- paste(method,sep="", collapse = "|")
     warning("'method' is deprecated. Please use 'methods' instead.")
@@ -361,28 +392,50 @@ compress_number_line <- function(x, method = c("exact", "across","chain","aligns
     m <- methods
   }
 
+  err <- err_match_ref_len(m, "", 1, "methods")
+  if(err != F) stop(err, call. = F)
+  err <- err_object_types(m, "methods", "character")
+  if(err != F) stop(err, call. = F)
+  err <- err_overlap_methods_1(overlap_methods = m, "methods")
+  if(err != F) stop(err, call. = F)
+  err <- err_object_types(collapse, "collapse", "logical")
+  if(err != F) stop(err, call. = F)
+  err <- err_match_ref_len(collapse, "", 1, "collapse")
+  if(err != F) stop(err, call. = F)
+  err <- err_missing_check(collapse, "collapse")
+  if(err != F) stop(err, call. = F)
+
+  err <- err_object_types(deduplicate, "deduplicate", "logical")
+  if(err != F) stop(err, call. = F)
+  err <- err_match_ref_len(deduplicate, "", 1, "deduplicate")
+  if(err != F) stop(err, call. = F)
+  err <- err_missing_check(deduplicate, "deduplicate")
+  if(err != F) stop(err, call. = F)
+
   if(any(duplicated(x@id) | is.na(x@id))) x@id <- 1:length(x@id)
-  #x <- diyar::reverse_number_line(x, "decreasing")
+  #x <- reverse_number_line(x, "decreasing")
 
   j <- 1
   t <- rep(0, length(x))
-  if(length(collapse)==1) collapse <- rep(collapse, length(x))
-  while (min(t) ==0 & j<=length(x)){
-    l <- x[t==0][1]
-    h <- (x@id == l@id | diyar::overlaps(x, l, methods=m)) & ifelse(collapse, TRUE, (t!=1))
+  if(length(collapse) == 1) collapse <- rep(collapse, length(x))
+  while (min(t) == 0 & j<=length(x)){
+    l <- x[t == 0][1]
+    lg <- overlaps(x, l, methods = m)
+    lg[is.na(lg)] <- F
+    h <- (x@id == l@id | lg) & ifelse(collapse, TRUE, (t != 1))
 
     if(length(h)>=1){
       mx_in <- ifelse(length(x[h & x@.Data >=0]) >0, max(x[h & x@.Data >=0]@.Data), 0)
       mx_dc <- ifelse(length(x[h & x@.Data  <0]) >0, max(abs(x[h & x@.Data <0]@.Data)), 0)
 
       if(mx_in >= mx_dc){
-        x[h] <- number_line(min(diyar::start_point(x)[h]),
-                            max(diyar::end_point(x)[h]),
+        x[h] <- number_line(min(start_point(x)[h]),
+                            max(end_point(x)[h]),
                             gid = sort(x[h])[1]@id,
                             id = x[h]@id)
       }else{
-        x[h] <- number_line(max(diyar::end_point(x)[h]),
-                            min(diyar::start_point(x)[h]),
+        x[h] <- number_line(max(end_point(x)[h]),
+                            min(start_point(x)[h]),
                             gid = sort(x[h])[1]@id,
                             id = x[h]@id)
       }
@@ -415,19 +468,37 @@ compress_number_line <- function(x, method = c("exact", "across","chain","aligns
 #'
 #' @export
 number_line_sequence <- function(x, by=1, length.out = NULL){
-  if(missing(x)) stop("argument 'x' is missing, with no default")
-  if(!diyar::is.number_line(x)) stop(paste0("'x' is not a number_line object"))
+  if(missing(x)) stop("argument `x` is missing, with no default", call. = F)
+  err <- err_object_types(x, "x", "number_line")
+  if(err != F) stop(err, call. = F)
+  if(length(x)==0) return(x)
+  err <- err_match_ref_len(by, "x", c(1, length(x)), "by")
+  if(err != F) stop(err, call. = F)
+  err <- err_object_types(by, "by", c("numeric", "integer"))
+  if(err != F) stop(err, call. = F)
+  err <- err_missing_check(by, "by")
+  if(err != F) stop(err, call. = F)
+
+  errs_l <- finite_check(x@start)
+  errs_r <- finite_check(x@.Data)
+
+  if(errs_l != T | errs_r != T){
+    errs <- paste0("`x` must have finite left and right points:\n",
+                   ifelse(errs_l != T, paste0("X - There are non-finite values in `left_point(x)", errs_l, "`.\n"), ""),
+                   ifelse(errs_r != T, paste0("X - There are non-finite values in `right_point(x)", errs_r, "`."), ""))
+    stop(errs, call. = F)
+  }
 
-  fn_check <- finite_check(x)
-  if(fn_check!=T) stop(paste0("Finite values for 'x' required in ",fn_check))
 
   fn_check <- finite_check(by)
-  if(fn_check!=T) stop(paste0("Finite values for 'by' required in ",fn_check))
+  if(fn_check!=T) stop(paste0("`by` must have finite values:\n",
+                              paste0("X - There are non-finite values in `by",fn_check, "`.")),
+                       call. = F)
 
   by <- ifelse(is.nan(x@.Data/abs(x@.Data)), by , x@.Data/abs(x@.Data)  * abs(by))
   if(is.null(length.out)){
     mapply(seq, from=left_point(x), to = right_point(x), by=by, SIMPLIFY = F)
   }else{
-    mapply(seq, from=diyar::left_point(x), to = diyar::right_point(x), length.out = length.out, SIMPLIFY = F)
+    mapply(seq, from=left_point(x), to = right_point(x), length.out = length.out, SIMPLIFY = F)
   }
 }
